#
# spec file for package ghc-bifunctors
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name bifunctors
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        5.5.3
Release:        2.4
Summary:        Collection Haskell 98 bifunctors, bifoldables and bitraversables
License:        BSD-2-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-transformers-compat-devel
%endif

%description
Bifunctor, bifoldable, and bitraversable instances for Haskell 98.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown

%changelog
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update bifunctors to version 5.5.3.
  5.5.3 [2018.07.04]
  - -----------------
  * Make `biliftA2` a class method of `Biapplicative`.
  * Add the `traverseBia`, `sequenceBia`, and `traverseBiaWith` functions for
    traversing a `Traversable` container in a `Biapplicative`.
  * Avoid incurring some dependencies when using recent GHCs.
* Mon May 14 2018 psimons@suse.com
- Update bifunctors to version 5.5.2 revision 2.
  * `Data.Bifunctor.TH` now derives `bimap`/`bitraverse`
    implementations for empty data types that are strict in the argument.
  * `Data.Bifunctor.TH` no longer derives `bifoldr`/`bifoldMap` implementations
    that error on empty data types. Instead, they simply return the folded state
    (for `bifoldr`) or `mempty` (for `bifoldMap`).
  * When using `Data.Bifunctor.TH` to derive `Bifunctor` or `Bitraversable`
    instances for data types where the last two type variables are at phantom
    roles, generated `bimap`/`bitraverse` implementations now use `coerce` for
    efficiency.
  * Add `Options` to `Data.Bifunctor.TH`, along with variants of existing
    functions that take `Options` as an argument. For now, the only configurable
    option is whether derived instances for empty data types should use the
    `EmptyCase` extension (this is disabled by default).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 5.4.2 with cabal2obs.
* Thu Dec  8 2016 psimons@suse.com
- Update to version 5.4.1 revision 1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 5.4.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 5.2 revision 0 with cabal2obs.
* Wed Jan 20 2016 mimi.vx@gmail.com
- update to 5.2
  * dded several Arrow-like instances for Tannen so we can use it as the Cayley
    construction if needed.
  * Added Data.Bifunctor.Sum
  * Added BifunctorFunctor, BifunctorMonad and BifunctorComonad.
* Thu Dec 17 2015 mimi.vx@gmail.com
- update to 5.1
  * Added Data.Bifunctor.Fix
  * Added Data.Bifunctor.TH, which permits TemplateHaskell-based deriving
    of Bifunctor, Bifoldable and Bitraversable instances.
  * Simplified Bitraversable.
* Thu Aug  6 2015 mimi.vx@gmail.com
- update to version 5
  * Inverted the dependency on semigroupoids. We can support a much wider array of base
  versions than it can.
  * Added flags
* Thu May 21 2015 mimi.vx@gmail.com
- correct licence to BSD-2-Clause
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
